aboutsummaryrefslogtreecommitdiffstats
path: root/src/algo_factory/algo_factory.h
diff options
context:
space:
mode:
authorlloyd <[email protected]>2009-03-02 06:58:45 +0000
committerlloyd <[email protected]>2009-03-02 06:58:45 +0000
commit6a0d23c063d1b7d52fd0ff780d61f4b602faa26e (patch)
tree95fa78a8d17de089d72333b36b923a1e3f423ed1 /src/algo_factory/algo_factory.h
parent609339f6237affd7041084382c92320d9768f47f (diff)
Fix misspelled words in algo_factory.{cpp,h}, from Charles Brockman in bug 40
Diffstat (limited to 'src/algo_factory/algo_factory.h')
-rw-r--r--src/algo_factory/algo_factory.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/algo_factory/algo_factory.h b/src/algo_factory/algo_factory.h
index 9c989b749..e7e8ac07b 100644
--- a/src/algo_factory/algo_factory.h
+++ b/src/algo_factory/algo_factory.h
@@ -31,11 +31,11 @@ class BOTAN_DLL Algorithm_Factory
{
public:
/**
* Contructor
* @param engines the list of engines to use
* @param mf a mutex factory
*/
- Algorithm_Factory(const std::vector<Engine*>& engines,
+ Algorithm_Factory(const std::vector<Engine*>& engines_in,
Mutex_Factory& mf);
/**
@@ -31,11 +31,11 @@ class BOTAN_DLL Algorithm_Factory
public:
/**
- * Contructor
- * @param engines the list of engines to use
+ * Constructor
+ * @param engines_in the list of engines to use
* @param mf a mutex factory
*/